.. mete0r.distutils.virtualenv documentation master file, created by
   sphinx-quickstart on Mon Nov 30 18:51:11 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.rst

.. include:: ../../CHANGES.rst
